# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSamlCertificateResult',
    'AwaitableGetSamlCertificateResult',
    'get_saml_certificate',
    'get_saml_certificate_output',
]

@pulumi.output_type
class GetSamlCertificateResult:
    """
    A collection of values returned by getSamlCertificate.
    """
    def __init__(__self__, certificate_id=None, content=None, expires_at=None, id=None, origin=None, type=None):
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if expires_at and not isinstance(expires_at, str):
            raise TypeError("Expected argument 'expires_at' to be a str")
        pulumi.set(__self__, "expires_at", expires_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if origin and not isinstance(origin, str):
            raise TypeError("Expected argument 'origin' to be a str")
        pulumi.set(__self__, "origin", origin)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> _builtins.str:
        """
        The ID of the SAML certificate
        """
        return pulumi.get(self, "certificate_id")

    @_builtins.property
    @pulumi.getter
    def content(self) -> _builtins.str:
        """
        The content of the SAML certificate
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> _builtins.str:
        """
        The expiration date and time of the SAML certificate
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def origin(self) -> _builtins.str:
        """
        The origin of the SAML certificate. Possible values are: `scaleway`, `identity_provider`.
        """
        return pulumi.get(self, "origin")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        return pulumi.get(self, "type")


class AwaitableGetSamlCertificateResult(GetSamlCertificateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSamlCertificateResult(
            certificate_id=self.certificate_id,
            content=self.content,
            expires_at=self.expires_at,
            id=self.id,
            origin=self.origin,
            type=self.type)


def get_saml_certificate(certificate_id: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSamlCertificateResult:
    """
    Get information about a SAML certificate. This data source allows you to retrieve information about a specific SAML certificate by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    ### Get information about a SAML certificate
    main = scaleway.iam.get_saml_certificate(certificate_id="22222222-2222-2222-2222-222222222222")
    ```


    :param _builtins.str certificate_id: The ID of the SAML certificate
    """
    __args__ = dict()
    __args__['certificateId'] = certificate_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:iam/getSamlCertificate:getSamlCertificate', __args__, opts=opts, typ=GetSamlCertificateResult).value

    return AwaitableGetSamlCertificateResult(
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        content=pulumi.get(__ret__, 'content'),
        expires_at=pulumi.get(__ret__, 'expires_at'),
        id=pulumi.get(__ret__, 'id'),
        origin=pulumi.get(__ret__, 'origin'),
        type=pulumi.get(__ret__, 'type'))
def get_saml_certificate_output(certificate_id: Optional[pulumi.Input[_builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSamlCertificateResult]:
    """
    Get information about a SAML certificate. This data source allows you to retrieve information about a specific SAML certificate by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    ### Get information about a SAML certificate
    main = scaleway.iam.get_saml_certificate(certificate_id="22222222-2222-2222-2222-222222222222")
    ```


    :param _builtins.str certificate_id: The ID of the SAML certificate
    """
    __args__ = dict()
    __args__['certificateId'] = certificate_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:iam/getSamlCertificate:getSamlCertificate', __args__, opts=opts, typ=GetSamlCertificateResult)
    return __ret__.apply(lambda __response__: GetSamlCertificateResult(
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        content=pulumi.get(__response__, 'content'),
        expires_at=pulumi.get(__response__, 'expires_at'),
        id=pulumi.get(__response__, 'id'),
        origin=pulumi.get(__response__, 'origin'),
        type=pulumi.get(__response__, 'type')))
