# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ExporterArgs', 'Exporter']

@pulumi.input_type
class ExporterArgs:
    def __init__(__self__, *,
                 datasource_id: pulumi.Input[_builtins.str],
                 datadog_destination: Optional[pulumi.Input['ExporterDatadogDestinationArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 exported_products: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 otlp_destination: Optional[pulumi.Input['ExporterOtlpDestinationArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Exporter resource.
        :param pulumi.Input[_builtins.str] datasource_id: ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        :param pulumi.Input['ExporterDatadogDestinationArgs'] datadog_destination: Datadog destination configuration. Cannot be used with `otlp_destination`.
        :param pulumi.Input[_builtins.str] description: Description of the data export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exported_products: List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        :param pulumi.Input[_builtins.str] name: Name of the data export.
        :param pulumi.Input['ExporterOtlpDestinationArgs'] otlp_destination: OTLP destination configuration. Cannot be used with `datadog_destination`.
        :param pulumi.Input[_builtins.str] project_id: ) The ID of the Project.
        :param pulumi.Input[_builtins.str] region: ) The region where the exporter is located.
        """
        pulumi.set(__self__, "datasource_id", datasource_id)
        if datadog_destination is not None:
            pulumi.set(__self__, "datadog_destination", datadog_destination)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if exported_products is not None:
            pulumi.set(__self__, "exported_products", exported_products)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if otlp_destination is not None:
            pulumi.set(__self__, "otlp_destination", otlp_destination)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="datasourceId")
    def datasource_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        """
        return pulumi.get(self, "datasource_id")

    @datasource_id.setter
    def datasource_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "datasource_id", value)

    @_builtins.property
    @pulumi.getter(name="datadogDestination")
    def datadog_destination(self) -> Optional[pulumi.Input['ExporterDatadogDestinationArgs']]:
        """
        Datadog destination configuration. Cannot be used with `otlp_destination`.
        """
        return pulumi.get(self, "datadog_destination")

    @datadog_destination.setter
    def datadog_destination(self, value: Optional[pulumi.Input['ExporterDatadogDestinationArgs']]):
        pulumi.set(self, "datadog_destination", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the data export.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="exportedProducts")
    def exported_products(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        """
        return pulumi.get(self, "exported_products")

    @exported_products.setter
    def exported_products(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "exported_products", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the data export.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="otlpDestination")
    def otlp_destination(self) -> Optional[pulumi.Input['ExporterOtlpDestinationArgs']]:
        """
        OTLP destination configuration. Cannot be used with `datadog_destination`.
        """
        return pulumi.get(self, "otlp_destination")

    @otlp_destination.setter
    def otlp_destination(self, value: Optional[pulumi.Input['ExporterOtlpDestinationArgs']]):
        pulumi.set(self, "otlp_destination", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ) The ID of the Project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ) The region where the exporter is located.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _ExporterState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 datadog_destination: Optional[pulumi.Input['ExporterDatadogDestinationArgs']] = None,
                 datasource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 exported_products: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 otlp_destination: Optional[pulumi.Input['ExporterOtlpDestinationArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Exporter resources.
        :param pulumi.Input[_builtins.str] created_at: Date and time of creation (RFC 3339 format).
        :param pulumi.Input['ExporterDatadogDestinationArgs'] datadog_destination: Datadog destination configuration. Cannot be used with `otlp_destination`.
        :param pulumi.Input[_builtins.str] datasource_id: ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        :param pulumi.Input[_builtins.str] description: Description of the data export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exported_products: List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        :param pulumi.Input[_builtins.str] name: Name of the data export.
        :param pulumi.Input['ExporterOtlpDestinationArgs'] otlp_destination: OTLP destination configuration. Cannot be used with `datadog_destination`.
        :param pulumi.Input[_builtins.str] project_id: ) The ID of the Project.
        :param pulumi.Input[_builtins.str] region: ) The region where the exporter is located.
        :param pulumi.Input[_builtins.str] status: Status of the data export (`creating`, `ready`, `error`).
        :param pulumi.Input[_builtins.str] updated_at: Date and time of last update (RFC 3339 format).
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if datadog_destination is not None:
            pulumi.set(__self__, "datadog_destination", datadog_destination)
        if datasource_id is not None:
            pulumi.set(__self__, "datasource_id", datasource_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if exported_products is not None:
            pulumi.set(__self__, "exported_products", exported_products)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if otlp_destination is not None:
            pulumi.set(__self__, "otlp_destination", otlp_destination)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date and time of creation (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="datadogDestination")
    def datadog_destination(self) -> Optional[pulumi.Input['ExporterDatadogDestinationArgs']]:
        """
        Datadog destination configuration. Cannot be used with `otlp_destination`.
        """
        return pulumi.get(self, "datadog_destination")

    @datadog_destination.setter
    def datadog_destination(self, value: Optional[pulumi.Input['ExporterDatadogDestinationArgs']]):
        pulumi.set(self, "datadog_destination", value)

    @_builtins.property
    @pulumi.getter(name="datasourceId")
    def datasource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        """
        return pulumi.get(self, "datasource_id")

    @datasource_id.setter
    def datasource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "datasource_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the data export.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="exportedProducts")
    def exported_products(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        """
        return pulumi.get(self, "exported_products")

    @exported_products.setter
    def exported_products(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "exported_products", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the data export.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="otlpDestination")
    def otlp_destination(self) -> Optional[pulumi.Input['ExporterOtlpDestinationArgs']]:
        """
        OTLP destination configuration. Cannot be used with `datadog_destination`.
        """
        return pulumi.get(self, "otlp_destination")

    @otlp_destination.setter
    def otlp_destination(self, value: Optional[pulumi.Input['ExporterOtlpDestinationArgs']]):
        pulumi.set(self, "otlp_destination", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ) The ID of the Project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ) The region where the exporter is located.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the data export (`creating`, `ready`, `error`).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date and time of last update (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("scaleway:observability/exporter:Exporter")
class Exporter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 datadog_destination: Optional[pulumi.Input[Union['ExporterDatadogDestinationArgs', 'ExporterDatadogDestinationArgsDict']]] = None,
                 datasource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 exported_products: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 otlp_destination: Optional[pulumi.Input[Union['ExporterOtlpDestinationArgs', 'ExporterOtlpDestinationArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `observability.Exporter` resource allows you to create and manage [data exports](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#data-exports) in Scaleway's Cockpit. Data exports send metrics and logs from Scaleway products to external destinations like Datadog or OTLP-compatible endpoints.

        Refer to Cockpit's [product documentation](https://www.scaleway.com/en/docs/observability/cockpit/concepts/) and [API documentation](https://www.scaleway.com/en/developers/api/cockpit/regional-api) for more information.

        ## Example Usage

        ### Datadog destination

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        project = scaleway.account.get_project(name="default")
        scaleway_metrics = scaleway.observability.get_sources(project_id=project.id,
            origin="scaleway",
            type="metrics")
        main = scaleway.observability.Exporter("main",
            project_id=project.id,
            datasource_id=scaleway_metrics.sources[0].id,
            name="my-datadog-exporter",
            exported_products=["all"],
            datadog_destination={
                "api_key": datadog_api_key,
                "endpoint": "https://api.datadoghq.com",
            })
        ```

        ### OTLP destination

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        project = scaleway.account.get_project(name="default")
        scaleway_metrics = scaleway.observability.get_sources(project_id=project.id,
            origin="scaleway",
            type="metrics")
        otlp_target = scaleway.observability.Source("otlp_target",
            project_id=project.id,
            name="otlp-target",
            type="metrics",
            retention_days=31)
        main = scaleway.observability.Exporter("main",
            project_id=project.id,
            datasource_id=scaleway_metrics.sources[0].id,
            name="my-otlp-exporter",
            exported_products=[
                "lb",
                "object-storage",
                "rdb",
            ],
            otlp_destination={
                "endpoint": otlp_target.push_url,
            })
        ```

        ## Import

        Import an exporter using the regional ID:

        bash

        ```sh
        $ pulumi import scaleway:observability/exporter:Exporter main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ExporterDatadogDestinationArgs', 'ExporterDatadogDestinationArgsDict']] datadog_destination: Datadog destination configuration. Cannot be used with `otlp_destination`.
        :param pulumi.Input[_builtins.str] datasource_id: ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        :param pulumi.Input[_builtins.str] description: Description of the data export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exported_products: List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        :param pulumi.Input[_builtins.str] name: Name of the data export.
        :param pulumi.Input[Union['ExporterOtlpDestinationArgs', 'ExporterOtlpDestinationArgsDict']] otlp_destination: OTLP destination configuration. Cannot be used with `datadog_destination`.
        :param pulumi.Input[_builtins.str] project_id: ) The ID of the Project.
        :param pulumi.Input[_builtins.str] region: ) The region where the exporter is located.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExporterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `observability.Exporter` resource allows you to create and manage [data exports](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#data-exports) in Scaleway's Cockpit. Data exports send metrics and logs from Scaleway products to external destinations like Datadog or OTLP-compatible endpoints.

        Refer to Cockpit's [product documentation](https://www.scaleway.com/en/docs/observability/cockpit/concepts/) and [API documentation](https://www.scaleway.com/en/developers/api/cockpit/regional-api) for more information.

        ## Example Usage

        ### Datadog destination

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        project = scaleway.account.get_project(name="default")
        scaleway_metrics = scaleway.observability.get_sources(project_id=project.id,
            origin="scaleway",
            type="metrics")
        main = scaleway.observability.Exporter("main",
            project_id=project.id,
            datasource_id=scaleway_metrics.sources[0].id,
            name="my-datadog-exporter",
            exported_products=["all"],
            datadog_destination={
                "api_key": datadog_api_key,
                "endpoint": "https://api.datadoghq.com",
            })
        ```

        ### OTLP destination

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        project = scaleway.account.get_project(name="default")
        scaleway_metrics = scaleway.observability.get_sources(project_id=project.id,
            origin="scaleway",
            type="metrics")
        otlp_target = scaleway.observability.Source("otlp_target",
            project_id=project.id,
            name="otlp-target",
            type="metrics",
            retention_days=31)
        main = scaleway.observability.Exporter("main",
            project_id=project.id,
            datasource_id=scaleway_metrics.sources[0].id,
            name="my-otlp-exporter",
            exported_products=[
                "lb",
                "object-storage",
                "rdb",
            ],
            otlp_destination={
                "endpoint": otlp_target.push_url,
            })
        ```

        ## Import

        Import an exporter using the regional ID:

        bash

        ```sh
        $ pulumi import scaleway:observability/exporter:Exporter main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ExporterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExporterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 datadog_destination: Optional[pulumi.Input[Union['ExporterDatadogDestinationArgs', 'ExporterDatadogDestinationArgsDict']]] = None,
                 datasource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 exported_products: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 otlp_destination: Optional[pulumi.Input[Union['ExporterOtlpDestinationArgs', 'ExporterOtlpDestinationArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExporterArgs.__new__(ExporterArgs)

            __props__.__dict__["datadog_destination"] = datadog_destination
            if datasource_id is None and not opts.urn:
                raise TypeError("Missing required property 'datasource_id'")
            __props__.__dict__["datasource_id"] = datasource_id
            __props__.__dict__["description"] = description
            __props__.__dict__["exported_products"] = exported_products
            __props__.__dict__["name"] = name
            __props__.__dict__["otlp_destination"] = otlp_destination
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(Exporter, __self__).__init__(
            'scaleway:observability/exporter:Exporter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            datadog_destination: Optional[pulumi.Input[Union['ExporterDatadogDestinationArgs', 'ExporterDatadogDestinationArgsDict']]] = None,
            datasource_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            exported_products: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            otlp_destination: Optional[pulumi.Input[Union['ExporterOtlpDestinationArgs', 'ExporterOtlpDestinationArgsDict']]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'Exporter':
        """
        Get an existing Exporter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Date and time of creation (RFC 3339 format).
        :param pulumi.Input[Union['ExporterDatadogDestinationArgs', 'ExporterDatadogDestinationArgsDict']] datadog_destination: Datadog destination configuration. Cannot be used with `otlp_destination`.
        :param pulumi.Input[_builtins.str] datasource_id: ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        :param pulumi.Input[_builtins.str] description: Description of the data export.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] exported_products: List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        :param pulumi.Input[_builtins.str] name: Name of the data export.
        :param pulumi.Input[Union['ExporterOtlpDestinationArgs', 'ExporterOtlpDestinationArgsDict']] otlp_destination: OTLP destination configuration. Cannot be used with `datadog_destination`.
        :param pulumi.Input[_builtins.str] project_id: ) The ID of the Project.
        :param pulumi.Input[_builtins.str] region: ) The region where the exporter is located.
        :param pulumi.Input[_builtins.str] status: Status of the data export (`creating`, `ready`, `error`).
        :param pulumi.Input[_builtins.str] updated_at: Date and time of last update (RFC 3339 format).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExporterState.__new__(_ExporterState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["datadog_destination"] = datadog_destination
        __props__.__dict__["datasource_id"] = datasource_id
        __props__.__dict__["description"] = description
        __props__.__dict__["exported_products"] = exported_products
        __props__.__dict__["name"] = name
        __props__.__dict__["otlp_destination"] = otlp_destination
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_at"] = updated_at
        return Exporter(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date and time of creation (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="datadogDestination")
    def datadog_destination(self) -> pulumi.Output[Optional['outputs.ExporterDatadogDestination']]:
        """
        Datadog destination configuration. Cannot be used with `otlp_destination`.
        """
        return pulumi.get(self, "datadog_destination")

    @_builtins.property
    @pulumi.getter(name="datasourceId")
    def datasource_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the data source linked to the data export. Use `observability_get_sources` to find available data sources.
        """
        return pulumi.get(self, "datasource_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the data export.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="exportedProducts")
    def exported_products(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of Scaleway products to export. Use `["all"]` to export all products. Use `observability_get_products` for valid product names. Defaults to `["all"]`.
        """
        return pulumi.get(self, "exported_products")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the data export.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="otlpDestination")
    def otlp_destination(self) -> pulumi.Output[Optional['outputs.ExporterOtlpDestination']]:
        """
        OTLP destination configuration. Cannot be used with `datadog_destination`.
        """
        return pulumi.get(self, "otlp_destination")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        ) The ID of the Project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ) The region where the exporter is located.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the data export (`creating`, `ready`, `error`).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date and time of last update (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

