# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ConnectionBgpConfigIpv4',
    'ConnectionBgpConfigIpv6',
    'ConnectionBgpSessionIpv4',
    'ConnectionBgpSessionIpv6',
    'ConnectionEspCipher',
    'ConnectionIkev2Cipher',
    'GatewayPublicConfig',
    'GetConnectionBgpConfigIpv4Result',
    'GetConnectionBgpConfigIpv6Result',
    'GetConnectionBgpSessionIpv4Result',
    'GetConnectionBgpSessionIpv6Result',
    'GetConnectionEspCipherResult',
    'GetConnectionIkev2CipherResult',
    'GetGatewayPublicConfigResult',
]

@pulumi.output_type
class ConnectionBgpConfigIpv4(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "routingPolicyId":
            suggest = "routing_policy_id"
        elif key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpConfigIpv4. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpConfigIpv4.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpConfigIpv4.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 routing_policy_id: _builtins.str,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None):
        """
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        """
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")


@pulumi.output_type
class ConnectionBgpConfigIpv6(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "routingPolicyId":
            suggest = "routing_policy_id"
        elif key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpConfigIpv6. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpConfigIpv6.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpConfigIpv6.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 routing_policy_id: _builtins.str,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None):
        """
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        """
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")


@pulumi.output_type
class ConnectionBgpSessionIpv4(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"
        elif key == "routingPolicyId":
            suggest = "routing_policy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpSessionIpv4. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpSessionIpv4.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpSessionIpv4.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None,
                 routing_policy_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        """
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if routing_policy_id is not None:
            pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[_builtins.str]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class ConnectionBgpSessionIpv6(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "peerPrivateIp":
            suggest = "peer_private_ip"
        elif key == "privateIp":
            suggest = "private_ip"
        elif key == "routingPolicyId":
            suggest = "routing_policy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionBgpSessionIpv6. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionBgpSessionIpv6.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionBgpSessionIpv6.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 peer_private_ip: Optional[_builtins.str] = None,
                 private_ip: Optional[_builtins.str] = None,
                 routing_policy_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        :param _builtins.str routing_policy_id: The routing policy ID used for this BGP session.
        """
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if routing_policy_id is not None:
            pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[_builtins.str]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[_builtins.str]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class ConnectionEspCipher(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dhGroup":
            suggest = "dh_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionEspCipher. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionEspCipher.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionEspCipher.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 encryption: _builtins.str,
                 dh_group: Optional[_builtins.str] = None,
                 integrity: Optional[_builtins.str] = None):
        """
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "encryption", encryption)
        if dh_group is not None:
            pulumi.set(__self__, "dh_group", dh_group)
        if integrity is not None:
            pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> Optional[_builtins.str]:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> Optional[_builtins.str]:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class ConnectionIkev2Cipher(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dhGroup":
            suggest = "dh_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionIkev2Cipher. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionIkev2Cipher.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionIkev2Cipher.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 encryption: _builtins.str,
                 dh_group: Optional[_builtins.str] = None,
                 integrity: Optional[_builtins.str] = None):
        """
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "encryption", encryption)
        if dh_group is not None:
            pulumi.set(__self__, "dh_group", dh_group)
        if integrity is not None:
            pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> Optional[_builtins.str]:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> Optional[_builtins.str]:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class GatewayPublicConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipamIpv4Id":
            suggest = "ipam_ipv4_id"
        elif key == "ipamIpv6Id":
            suggest = "ipam_ipv6_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GatewayPublicConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GatewayPublicConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GatewayPublicConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ipam_ipv4_id: Optional[_builtins.str] = None,
                 ipam_ipv6_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str ipam_ipv4_id: The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        :param _builtins.str ipam_ipv6_id: The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
        if ipam_ipv4_id is not None:
            pulumi.set(__self__, "ipam_ipv4_id", ipam_ipv4_id)
        if ipam_ipv6_id is not None:
            pulumi.set(__self__, "ipam_ipv6_id", ipam_ipv6_id)

    @_builtins.property
    @pulumi.getter(name="ipamIpv4Id")
    def ipam_ipv4_id(self) -> Optional[_builtins.str]:
        """
        The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        """
        return pulumi.get(self, "ipam_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamIpv6Id")
    def ipam_ipv6_id(self) -> Optional[_builtins.str]:
        """
        The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
        return pulumi.get(self, "ipam_ipv6_id")


@pulumi.output_type
class GetConnectionBgpConfigIpv4Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The ID of the routing policy to use for BGP route filtering
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The ID of the routing policy to use for BGP route filtering
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionBgpConfigIpv6Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The ID of the routing policy to use for BGP route filtering
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The ID of the routing policy to use for BGP route filtering
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionBgpSessionIpv4Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The routing policy ID
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionBgpSessionIpv6Result(dict):
    def __init__(__self__, *,
                 peer_private_ip: _builtins.str,
                 private_ip: _builtins.str,
                 routing_policy_id: _builtins.str):
        """
        :param _builtins.str peer_private_ip: The BGP peer IP on customer side
        :param _builtins.str private_ip: The BGP peer IP on Scaleway side
        :param _builtins.str routing_policy_id: The routing policy ID
        """
        pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        pulumi.set(__self__, "private_ip", private_ip)
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on customer side
        """
        return pulumi.get(self, "peer_private_ip")

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> _builtins.str:
        """
        The BGP peer IP on Scaleway side
        """
        return pulumi.get(self, "private_ip")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> _builtins.str:
        """
        The routing policy ID
        """
        return pulumi.get(self, "routing_policy_id")


@pulumi.output_type
class GetConnectionEspCipherResult(dict):
    def __init__(__self__, *,
                 dh_group: _builtins.str,
                 encryption: _builtins.str,
                 integrity: _builtins.str):
        """
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "dh_group", dh_group)
        pulumi.set(__self__, "encryption", encryption)
        pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> _builtins.str:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> _builtins.str:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class GetConnectionIkev2CipherResult(dict):
    def __init__(__self__, *,
                 dh_group: _builtins.str,
                 encryption: _builtins.str,
                 integrity: _builtins.str):
        """
        :param _builtins.str dh_group: The Diffie-Hellman group
        :param _builtins.str encryption: The encryption algorithm
        :param _builtins.str integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "dh_group", dh_group)
        pulumi.set(__self__, "encryption", encryption)
        pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> _builtins.str:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> _builtins.str:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> _builtins.str:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")


@pulumi.output_type
class GetGatewayPublicConfigResult(dict):
    def __init__(__self__, *,
                 ipam_ipv4_id: _builtins.str,
                 ipam_ipv6_id: _builtins.str):
        """
        :param _builtins.str ipam_ipv4_id: The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway
        :param _builtins.str ipam_ipv6_id: The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway
        """
        pulumi.set(__self__, "ipam_ipv4_id", ipam_ipv4_id)
        pulumi.set(__self__, "ipam_ipv6_id", ipam_ipv6_id)

    @_builtins.property
    @pulumi.getter(name="ipamIpv4Id")
    def ipam_ipv4_id(self) -> _builtins.str:
        """
        The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway
        """
        return pulumi.get(self, "ipam_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamIpv6Id")
    def ipam_ipv6_id(self) -> _builtins.str:
        """
        The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway
        """
        return pulumi.get(self, "ipam_ipv6_id")


