# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCustomerGatewayResult',
    'AwaitableGetCustomerGatewayResult',
    'get_customer_gateway',
    'get_customer_gateway_output',
]

@pulumi.output_type
class GetCustomerGatewayResult:
    """
    A collection of values returned by getCustomerGateway.
    """
    def __init__(__self__, asn=None, created_at=None, customer_gateway_id=None, id=None, ipv4_public=None, ipv6_public=None, name=None, organization_id=None, project_id=None, region=None, tags=None, updated_at=None):
        if asn and not isinstance(asn, int):
            raise TypeError("Expected argument 'asn' to be a int")
        pulumi.set(__self__, "asn", asn)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if customer_gateway_id and not isinstance(customer_gateway_id, str):
            raise TypeError("Expected argument 'customer_gateway_id' to be a str")
        pulumi.set(__self__, "customer_gateway_id", customer_gateway_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv4_public and not isinstance(ipv4_public, str):
            raise TypeError("Expected argument 'ipv4_public' to be a str")
        pulumi.set(__self__, "ipv4_public", ipv4_public)
        if ipv6_public and not isinstance(ipv6_public, str):
            raise TypeError("Expected argument 'ipv6_public' to be a str")
        pulumi.set(__self__, "ipv6_public", ipv6_public)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> _builtins.int:
        """
        The AS Number of the customer gateway.
        """
        return pulumi.get(self, "asn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of creation of the customer gateway.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "customer_gateway_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> _builtins.str:
        """
        The public IPv4 address of the customer gateway.
        """
        return pulumi.get(self, "ipv4_public")

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> _builtins.str:
        """
        The public IPv6 address of the customer gateway.
        """
        return pulumi.get(self, "ipv6_public")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The Organization ID the customer gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        The tags associated with the customer gateway.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time of the last update of the customer gateway.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetCustomerGatewayResult(GetCustomerGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCustomerGatewayResult(
            asn=self.asn,
            created_at=self.created_at,
            customer_gateway_id=self.customer_gateway_id,
            id=self.id,
            ipv4_public=self.ipv4_public,
            ipv6_public=self.ipv6_public,
            name=self.name,
            organization_id=self.organization_id,
            project_id=self.project_id,
            region=self.region,
            tags=self.tags,
            updated_at=self.updated_at)


def get_customer_gateway(customer_gateway_id: Optional[_builtins.str] = None,
                         name: Optional[_builtins.str] = None,
                         project_id: Optional[_builtins.str] = None,
                         region: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCustomerGatewayResult:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by gateway ID
    my_gateway = scaleway.s2svpn.get_customer_gateway(customer_gateway_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_gateway = scaleway.s2svpn.get_customer_gateway(name="foobar")
    ```


    :param _builtins.str customer_gateway_id: The customer gateway ID.
           
           > **Note** You must specify at least one: `name` and/or `customer_gateway_id`.
    :param _builtins.str name: The name of the customer gateway.
    :param _builtins.str project_id: The ID of the project the customer gateway is associated with.
    :param _builtins.str region: `region`) The region in which the customer gateway exists.
    """
    __args__ = dict()
    __args__['customerGatewayId'] = customer_gateway_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:s2svpn/getCustomerGateway:getCustomerGateway', __args__, opts=opts, typ=GetCustomerGatewayResult).value

    return AwaitableGetCustomerGatewayResult(
        asn=pulumi.get(__ret__, 'asn'),
        created_at=pulumi.get(__ret__, 'created_at'),
        customer_gateway_id=pulumi.get(__ret__, 'customer_gateway_id'),
        id=pulumi.get(__ret__, 'id'),
        ipv4_public=pulumi.get(__ret__, 'ipv4_public'),
        ipv6_public=pulumi.get(__ret__, 'ipv6_public'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_customer_gateway_output(customer_gateway_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCustomerGatewayResult]:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by gateway ID
    my_gateway = scaleway.s2svpn.get_customer_gateway(customer_gateway_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_gateway = scaleway.s2svpn.get_customer_gateway(name="foobar")
    ```


    :param _builtins.str customer_gateway_id: The customer gateway ID.
           
           > **Note** You must specify at least one: `name` and/or `customer_gateway_id`.
    :param _builtins.str name: The name of the customer gateway.
    :param _builtins.str project_id: The ID of the project the customer gateway is associated with.
    :param _builtins.str region: `region`) The region in which the customer gateway exists.
    """
    __args__ = dict()
    __args__['customerGatewayId'] = customer_gateway_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:s2svpn/getCustomerGateway:getCustomerGateway', __args__, opts=opts, typ=GetCustomerGatewayResult)
    return __ret__.apply(lambda __response__: GetCustomerGatewayResult(
        asn=pulumi.get(__response__, 'asn'),
        created_at=pulumi.get(__response__, 'created_at'),
        customer_gateway_id=pulumi.get(__response__, 'customer_gateway_id'),
        id=pulumi.get(__response__, 'id'),
        ipv4_public=pulumi.get(__response__, 'ipv4_public'),
        ipv6_public=pulumi.get(__response__, 'ipv6_public'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at')))
