# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetExporterResult',
    'AwaitableGetExporterResult',
    'get_exporter',
    'get_exporter_output',
]

@pulumi.output_type
class GetExporterResult:
    """
    A collection of values returned by getExporter.
    """
    def __init__(__self__, created_at=None, datadog_destinations=None, datasource_id=None, description=None, exported_products=None, id=None, name=None, otlp_destinations=None, project_id=None, region=None, status=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if datadog_destinations and not isinstance(datadog_destinations, list):
            raise TypeError("Expected argument 'datadog_destinations' to be a list")
        pulumi.set(__self__, "datadog_destinations", datadog_destinations)
        if datasource_id and not isinstance(datasource_id, str):
            raise TypeError("Expected argument 'datasource_id' to be a str")
        pulumi.set(__self__, "datasource_id", datasource_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if exported_products and not isinstance(exported_products, list):
            raise TypeError("Expected argument 'exported_products' to be a list")
        pulumi.set(__self__, "exported_products", exported_products)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if otlp_destinations and not isinstance(otlp_destinations, list):
            raise TypeError("Expected argument 'otlp_destinations' to be a list")
        pulumi.set(__self__, "otlp_destinations", otlp_destinations)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Creation date (RFC 3339).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="datadogDestinations")
    def datadog_destinations(self) -> Sequence['outputs.GetExporterDatadogDestinationResult']:
        """
        Datadog destination configuration (endpoint only, API key is write-only).
        """
        return pulumi.get(self, "datadog_destinations")

    @_builtins.property
    @pulumi.getter(name="datasourceId")
    def datasource_id(self) -> _builtins.str:
        """
        ID of the linked data source.
        """
        return pulumi.get(self, "datasource_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the data export.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="exportedProducts")
    def exported_products(self) -> Sequence[_builtins.str]:
        """
        List of exported products.
        """
        return pulumi.get(self, "exported_products")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The regional ID of the exporter.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the data export.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="otlpDestinations")
    def otlp_destinations(self) -> Sequence['outputs.GetExporterOtlpDestinationResult']:
        """
        OTLP destination configuration.
        """
        return pulumi.get(self, "otlp_destinations")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of the data export (`creating`, `ready`, `error`).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Last update date (RFC 3339).
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetExporterResult(GetExporterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExporterResult(
            created_at=self.created_at,
            datadog_destinations=self.datadog_destinations,
            datasource_id=self.datasource_id,
            description=self.description,
            exported_products=self.exported_products,
            id=self.id,
            name=self.name,
            otlp_destinations=self.otlp_destinations,
            project_id=self.project_id,
            region=self.region,
            status=self.status,
            updated_at=self.updated_at)


def get_exporter(id: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 project_id: Optional[_builtins.str] = None,
                 region: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExporterResult:
    """
    Gets information about a [data export](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#data-exports) in Scaleway's Cockpit.

    Refer to Cockpit's [product documentation](https://www.scaleway.com/en/docs/observability/cockpit/concepts/) and [API documentation](https://www.scaleway.com/en/developers/api/cockpit/regional-api) for more information.

    ## Example Usage

    ### By ID

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.observability.get_exporter(id="fr-par/11111111-1111-1111-1111-111111111111")
    ```

    ### By name and project

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.observability.get_exporter(project_id="11111111-1111-1111-1111-111111111111",
        name="my-datadog-exporter")
    ```


    :param _builtins.str id: The regional ID of the exporter (`{region}/{id}`). If set, other filters are ignored.
    :param _builtins.str name: The name of the exporter.
    :param _builtins.str project_id: The project ID.
    :param _builtins.str region: The region. Defaults to the provider region.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:observability/getExporter:getExporter', __args__, opts=opts, typ=GetExporterResult).value

    return AwaitableGetExporterResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        datadog_destinations=pulumi.get(__ret__, 'datadog_destinations'),
        datasource_id=pulumi.get(__ret__, 'datasource_id'),
        description=pulumi.get(__ret__, 'description'),
        exported_products=pulumi.get(__ret__, 'exported_products'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        otlp_destinations=pulumi.get(__ret__, 'otlp_destinations'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_exporter_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetExporterResult]:
    """
    Gets information about a [data export](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#data-exports) in Scaleway's Cockpit.

    Refer to Cockpit's [product documentation](https://www.scaleway.com/en/docs/observability/cockpit/concepts/) and [API documentation](https://www.scaleway.com/en/developers/api/cockpit/regional-api) for more information.

    ## Example Usage

    ### By ID

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.observability.get_exporter(id="fr-par/11111111-1111-1111-1111-111111111111")
    ```

    ### By name and project

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.observability.get_exporter(project_id="11111111-1111-1111-1111-111111111111",
        name="my-datadog-exporter")
    ```


    :param _builtins.str id: The regional ID of the exporter (`{region}/{id}`). If set, other filters are ignored.
    :param _builtins.str name: The name of the exporter.
    :param _builtins.str project_id: The project ID.
    :param _builtins.str region: The region. Defaults to the provider region.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:observability/getExporter:getExporter', __args__, opts=opts, typ=GetExporterResult)
    return __ret__.apply(lambda __response__: GetExporterResult(
        created_at=pulumi.get(__response__, 'created_at'),
        datadog_destinations=pulumi.get(__response__, 'datadog_destinations'),
        datasource_id=pulumi.get(__response__, 'datasource_id'),
        description=pulumi.get(__response__, 'description'),
        exported_products=pulumi.get(__response__, 'exported_products'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        otlp_destinations=pulumi.get(__response__, 'otlp_destinations'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        updated_at=pulumi.get(__response__, 'updated_at')))
