# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'KeyRotationPolicyArgs',
    'KeyRotationPolicyArgsDict',
]

MYPY = False

if not MYPY:
    class KeyRotationPolicyArgsDict(TypedDict):
        rotation_period: pulumi.Input[_builtins.str]
        """
        – The period between key rotations (e.g., `"720h"` for 30 days).
        """
        next_rotation_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The date and time of the next scheduled rotation.
        """
elif False:
    KeyRotationPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class KeyRotationPolicyArgs:
    def __init__(__self__, *,
                 rotation_period: pulumi.Input[_builtins.str],
                 next_rotation_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] rotation_period: – The period between key rotations (e.g., `"720h"` for 30 days).
        :param pulumi.Input[_builtins.str] next_rotation_at: The date and time of the next scheduled rotation.
        """
        pulumi.set(__self__, "rotation_period", rotation_period)
        if next_rotation_at is not None:
            pulumi.set(__self__, "next_rotation_at", next_rotation_at)

    @_builtins.property
    @pulumi.getter(name="rotationPeriod")
    def rotation_period(self) -> pulumi.Input[_builtins.str]:
        """
        – The period between key rotations (e.g., `"720h"` for 30 days).
        """
        return pulumi.get(self, "rotation_period")

    @rotation_period.setter
    def rotation_period(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rotation_period", value)

    @_builtins.property
    @pulumi.getter(name="nextRotationAt")
    def next_rotation_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the next scheduled rotation.
        """
        return pulumi.get(self, "next_rotation_at")

    @next_rotation_at.setter
    def next_rotation_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "next_rotation_at", value)


