# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DeploymentEndpoint',
    'DeploymentEndpointService',
    'DeploymentPrivateNetwork',
    'DeploymentVolume',
    'GetDeploymentEndpointResult',
    'GetDeploymentEndpointServiceResult',
    'GetDeploymentPrivateNetworkResult',
    'GetDeploymentVolumeResult',
]

@pulumi.output_type
class DeploymentEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "privateNetworkId":
            suggest = "private_network_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: Optional[_builtins.str] = None,
                 private_network_id: Optional[_builtins.str] = None,
                 public: Optional[_builtins.bool] = None,
                 services: Optional[Sequence['outputs.DeploymentEndpointService']] = None):
        """
        :param _builtins.str id: The ID of the endpoint.
        :param _builtins.str private_network_id: Private network ID if the endpoint is private.
        :param _builtins.bool public: Whether the endpoint is public (true) or private (false).
        :param Sequence['DeploymentEndpointServiceArgs'] services: List of services exposed on the endpoint.
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if services is not None:
            pulumi.set(__self__, "services", services)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[_builtins.str]:
        """
        Private network ID if the endpoint is private.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter
    def public(self) -> Optional[_builtins.bool]:
        """
        Whether the endpoint is public (true) or private (false).
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter
    def services(self) -> Optional[Sequence['outputs.DeploymentEndpointService']]:
        """
        List of services exposed on the endpoint.
        """
        return pulumi.get(self, "services")


@pulumi.output_type
class DeploymentEndpointService(dict):
    def __init__(__self__, *,
                 name: Optional[_builtins.str] = None,
                 port: Optional[_builtins.int] = None,
                 url: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: Name of the OpenSearch deployment. If not specified, a random name will be generated.
        :param _builtins.int port: Service port number.
        :param _builtins.str url: Full URL to access the service (e.g., "https://abc-123.searchdb.fr-par.scw.cloud:9200").
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the OpenSearch deployment. If not specified, a random name will be generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Service port number.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[_builtins.str]:
        """
        Full URL to access the service (e.g., "https://abc-123.searchdb.fr-par.scw.cloud:9200").
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class DeploymentPrivateNetwork(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "privateNetworkId":
            suggest = "private_network_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentPrivateNetwork. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentPrivateNetwork.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentPrivateNetwork.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 private_network_id: _builtins.str):
        """
        :param _builtins.str private_network_id: Private network ID if the endpoint is private.
        """
        pulumi.set(__self__, "private_network_id", private_network_id)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        Private network ID if the endpoint is private.
        """
        return pulumi.get(self, "private_network_id")


@pulumi.output_type
class DeploymentVolume(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sizeInGb":
            suggest = "size_in_gb"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentVolume. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentVolume.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentVolume.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 size_in_gb: _builtins.int,
                 type: _builtins.str):
        """
        :param _builtins.int size_in_gb: Volume size in GB. Changing this forces recreation of the deployment.
        :param _builtins.str type: Volume type. Valid values are `sbs_5k` (5K IOPS) or `sbs_15k` (15K IOPS). Changing this forces recreation of the deployment.
        """
        pulumi.set(__self__, "size_in_gb", size_in_gb)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> _builtins.int:
        """
        Volume size in GB. Changing this forces recreation of the deployment.
        """
        return pulumi.get(self, "size_in_gb")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Volume type. Valid values are `sbs_5k` (5K IOPS) or `sbs_15k` (15K IOPS). Changing this forces recreation of the deployment.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetDeploymentEndpointResult(dict):
    def __init__(__self__, *,
                 id: _builtins.str,
                 private_network_id: _builtins.str,
                 public: _builtins.bool,
                 services: Sequence['outputs.GetDeploymentEndpointServiceResult']):
        """
        :param _builtins.str id: Endpoint ID
        :param _builtins.str private_network_id: Private network ID if applicable
        :param _builtins.bool public: Whether the endpoint is public
        :param Sequence['GetDeploymentEndpointServiceArgs'] services: List of services
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "private_network_id", private_network_id)
        pulumi.set(__self__, "public", public)
        pulumi.set(__self__, "services", services)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Endpoint ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        Private network ID if applicable
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter
    def public(self) -> _builtins.bool:
        """
        Whether the endpoint is public
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter
    def services(self) -> Sequence['outputs.GetDeploymentEndpointServiceResult']:
        """
        List of services
        """
        return pulumi.get(self, "services")


@pulumi.output_type
class GetDeploymentEndpointServiceResult(dict):
    def __init__(__self__, *,
                 name: _builtins.str,
                 port: _builtins.int,
                 url: _builtins.str):
        """
        :param _builtins.str name: The name of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
        :param _builtins.int port: Service port
        :param _builtins.str url: Service URL
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Service port
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        """
        Service URL
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class GetDeploymentPrivateNetworkResult(dict):
    def __init__(__self__, *,
                 private_network_id: _builtins.str):
        """
        :param _builtins.str private_network_id: UUID of the Private Network
        """
        pulumi.set(__self__, "private_network_id", private_network_id)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        UUID of the Private Network
        """
        return pulumi.get(self, "private_network_id")


@pulumi.output_type
class GetDeploymentVolumeResult(dict):
    def __init__(__self__, *,
                 size_in_gb: _builtins.int,
                 type: _builtins.str):
        """
        :param _builtins.int size_in_gb: Volume size in GB
        :param _builtins.str type: Volume type (sbs_5k, sbs_15k)
        """
        pulumi.set(__self__, "size_in_gb", size_in_gb)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> _builtins.int:
        """
        Volume size in GB
        """
        return pulumi.get(self, "size_in_gb")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Volume type (sbs_5k, sbs_15k)
        """
        return pulumi.get(self, "type")


