# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CustomerGatewayArgs', 'CustomerGateway']

@pulumi.input_type
class CustomerGatewayArgs:
    def __init__(__self__, *,
                 asn: pulumi.Input[_builtins.int],
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a CustomerGateway resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        """
        pulumi.set(__self__, "asn", asn)
        if ipv4_public is not None:
            pulumi.set(__self__, "ipv4_public", ipv4_public)
        if ipv6_public is not None:
            pulumi.set(__self__, "ipv6_public", ipv6_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> pulumi.Input[_builtins.int]:
        """
        The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "asn", value)

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv4 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv4_public")

    @ipv4_public.setter
    def ipv4_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv4_public", value)

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv6 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv6_public")

    @ipv6_public.setter
    def ipv6_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_public", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the customer gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the customer gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the customer gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the customer gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CustomerGatewayState:
    def __init__(__self__, *,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomerGateway resources.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the customer gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if ipv4_public is not None:
            pulumi.set(__self__, "ipv4_public", ipv4_public)
        if ipv6_public is not None:
            pulumi.set(__self__, "ipv6_public", ipv6_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "asn", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv4 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv4_public")

    @ipv4_public.setter
    def ipv4_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv4_public", value)

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv6 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv6_public")

    @ipv6_public.setter
    def ipv6_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_public", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the customer gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the customer gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the customer gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the customer gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the customer gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("scaleway:s2svpn/customerGateway:CustomerGateway")
class CustomerGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Site-to-Site VPN Customer Gateways.
        A customer gateway represents your external VPN endpoint (e.g., a firewall, router, or VPN appliance).

        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            asn=65000)
        ```

        ### With IPv6

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            ipv6_public="2001:db8::1",
            asn=65000)
        ```

        ### Using Instance Public IP

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpn_endpoint_ip = scaleway.instance.Ip("vpn_endpoint_ip")
        vpn_endpoint = scaleway.instance.Server("vpn_endpoint",
            name="vpn-endpoint",
            type="DEV1-S",
            image="ubuntu_jammy",
            ip_ids=[vpn_endpoint_ip.id])
        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public=vpn_endpoint_ip.address,
            asn=65000)
        ```

        ## Import

        Customer Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/customerGateway:CustomerGateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomerGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Site-to-Site VPN Customer Gateways.
        A customer gateway represents your external VPN endpoint (e.g., a firewall, router, or VPN appliance).

        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            asn=65000)
        ```

        ### With IPv6

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            ipv6_public="2001:db8::1",
            asn=65000)
        ```

        ### Using Instance Public IP

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpn_endpoint_ip = scaleway.instance.Ip("vpn_endpoint_ip")
        vpn_endpoint = scaleway.instance.Server("vpn_endpoint",
            name="vpn-endpoint",
            type="DEV1-S",
            image="ubuntu_jammy",
            ip_ids=[vpn_endpoint_ip.id])
        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public=vpn_endpoint_ip.address,
            asn=65000)
        ```

        ## Import

        Customer Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/customerGateway:CustomerGateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param CustomerGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomerGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomerGatewayArgs.__new__(CustomerGatewayArgs)

            if asn is None and not opts.urn:
                raise TypeError("Missing required property 'asn'")
            __props__.__dict__["asn"] = asn
            __props__.__dict__["ipv4_public"] = ipv4_public
            __props__.__dict__["ipv6_public"] = ipv6_public
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["updated_at"] = None
        super(CustomerGateway, __self__).__init__(
            'scaleway:s2svpn/customerGateway:CustomerGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asn: Optional[pulumi.Input[_builtins.int]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
            ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'CustomerGateway':
        """
        Get an existing CustomerGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the customer gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomerGatewayState.__new__(_CustomerGatewayState)

        __props__.__dict__["asn"] = asn
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["ipv4_public"] = ipv4_public
        __props__.__dict__["ipv6_public"] = ipv6_public
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return CustomerGateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> pulumi.Output[_builtins.int]:
        """
        The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        """
        return pulumi.get(self, "asn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> pulumi.Output[_builtins.str]:
        """
        The public IPv4 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv4_public")

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> pulumi.Output[_builtins.str]:
        """
        The public IPv6 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv6_public")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the customer gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the customer gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the customer gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the customer gateway should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of tags to apply to the customer gateway.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

