# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayArgs', 'Gateway']

@pulumi.input_type
class GatewayArgs:
    def __init__(__self__, *,
                 gateway_type: pulumi.Input[_builtins.str],
                 private_network_id: pulumi.Input[_builtins.str],
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Gateway resource.
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        pulumi.set(__self__, "gateway_type", gateway_type)
        pulumi.set(__self__, "private_network_id", private_network_id)
        if ipam_private_ipv4_id is not None:
            pulumi.set(__self__, "ipam_private_ipv4_id", ipam_private_ipv4_id)
        if ipam_private_ipv6_id is not None:
            pulumi.set(__self__, "ipam_private_ipv6_id", ipam_private_ipv6_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_configs is not None:
            pulumi.set(__self__, "public_configs", public_configs)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> pulumi.Input[_builtins.str]:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @gateway_type.setter
    def gateway_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "gateway_type", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Private Network to attach to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @ipam_private_ipv4_id.setter
    def ipam_private_ipv4_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv4_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @ipam_private_ipv6_id.setter
    def ipam_private_ipv6_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv6_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the VPN gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the VPN gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]:
        """
        The public endpoint configuration of the VPN gateway. See Public Config below.
        """
        return pulumi.get(self, "public_configs")

    @public_configs.setter
    def public_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]):
        pulumi.set(self, "public_configs", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the VPN gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the VPN gateway should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _GatewayState:
    def __init__(__self__, *,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Gateway resources.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the VPN gateway (typically 12876 for Scaleway).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the VPN gateway is associated with.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[_builtins.str] status: The status of the VPN gateway.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if gateway_type is not None:
            pulumi.set(__self__, "gateway_type", gateway_type)
        if ipam_private_ipv4_id is not None:
            pulumi.set(__self__, "ipam_private_ipv4_id", ipam_private_ipv4_id)
        if ipam_private_ipv6_id is not None:
            pulumi.set(__self__, "ipam_private_ipv6_id", ipam_private_ipv6_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_configs is not None:
            pulumi.set(__self__, "public_configs", public_configs)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The AS Number of the VPN gateway (typically 12876 for Scaleway).
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "asn", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @gateway_type.setter
    def gateway_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gateway_type", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @ipam_private_ipv4_id.setter
    def ipam_private_ipv4_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv4_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @ipam_private_ipv6_id.setter
    def ipam_private_ipv6_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv6_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the VPN gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the VPN gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Private Network to attach to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the VPN gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]:
        """
        The public endpoint configuration of the VPN gateway. See Public Config below.
        """
        return pulumi.get(self, "public_configs")

    @public_configs.setter
    def public_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]):
        pulumi.set(self, "public_configs", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the VPN gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the VPN gateway.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the VPN gateway should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("scaleway:s2svpn/gateway:Gateway")
class Gateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Site-to-Site VPN Gateways.
        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc = scaleway.network.Vpc("vpc", name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            vpc_id=vpc.id,
            ipv4_subnet={
                "subnet": "10.0.1.0/24",
            })
        gateway = scaleway.s2svpn.Gateway("gateway",
            name="my-vpn-gateway",
            gateway_type="VGW-S",
            private_network_id=pn.id)
        ```

        ## Import

        VPN Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/gateway:Gateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Site-to-Site VPN Gateways.
        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc = scaleway.network.Vpc("vpc", name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            vpc_id=vpc.id,
            ipv4_subnet={
                "subnet": "10.0.1.0/24",
            })
        gateway = scaleway.s2svpn.Gateway("gateway",
            name="my-vpn-gateway",
            gateway_type="VGW-S",
            private_network_id=pn.id)
        ```

        ## Import

        VPN Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/gateway:Gateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param GatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayArgs.__new__(GatewayArgs)

            if gateway_type is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_type'")
            __props__.__dict__["gateway_type"] = gateway_type
            __props__.__dict__["ipam_private_ipv4_id"] = ipam_private_ipv4_id
            __props__.__dict__["ipam_private_ipv6_id"] = ipam_private_ipv6_id
            __props__.__dict__["name"] = name
            if private_network_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_network_id'")
            __props__.__dict__["private_network_id"] = private_network_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["public_configs"] = public_configs
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["zone"] = zone
            __props__.__dict__["asn"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(Gateway, __self__).__init__(
            'scaleway:s2svpn/gateway:Gateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asn: Optional[pulumi.Input[_builtins.int]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
            ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
            ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            public_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'Gateway':
        """
        Get an existing Gateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the VPN gateway (typically 12876 for Scaleway).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the VPN gateway is associated with.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[_builtins.str] status: The status of the VPN gateway.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayState.__new__(_GatewayState)

        __props__.__dict__["asn"] = asn
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["gateway_type"] = gateway_type
        __props__.__dict__["ipam_private_ipv4_id"] = ipam_private_ipv4_id
        __props__.__dict__["ipam_private_ipv6_id"] = ipam_private_ipv6_id
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public_configs"] = public_configs
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["zone"] = zone
        return Gateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> pulumi.Output[_builtins.int]:
        """
        The AS Number of the VPN gateway (typically 12876 for Scaleway).
        """
        return pulumi.get(self, "asn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> pulumi.Output[_builtins.str]:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the VPN gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the VPN gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Private Network to attach to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the VPN gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> pulumi.Output[Sequence['outputs.GatewayPublicConfig']]:
        """
        The public endpoint configuration of the VPN gateway. See Public Config below.
        """
        return pulumi.get(self, "public_configs")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the VPN gateway should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the VPN gateway.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The list of tags to apply to the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `zone`) The zone in which the VPN gateway should be created.
        """
        return pulumi.get(self, "zone")

