# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 node_amount: pulumi.Input[_builtins.int],
                 node_type: pulumi.Input[_builtins.str],
                 version: pulumi.Input[_builtins.str],
                 volume_size_in_gb: pulumi.Input[_builtins.int],
                 volume_type: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input['ClusterPrivateNetworkArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input['ClusterPrivateNetworkArgs'] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        pulumi.set(__self__, "node_amount", node_amount)
        pulumi.set(__self__, "node_type", node_type)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        pulumi.set(__self__, "volume_type", volume_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> pulumi.Input[_builtins.int]:
        """
        Number of nodes in the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_amount")

    @node_amount.setter
    def node_amount(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "node_amount", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Input[_builtins.str]:
        """
        Node type to use for the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Input[_builtins.str]:
        """
        Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> pulumi.Input[_builtins.int]:
        """
        Volume size in GB. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "volume_size_in_gb", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "volume_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Kafka cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['ClusterPrivateNetworkArgs']]:
        """
        Private network endpoint information.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['ClusterPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_amount: Optional[pulumi.Input[_builtins.int]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input['ClusterPrivateNetworkArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_networks: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[_builtins.str] created_at: Date and time of cluster creation (RFC 3339 format).
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input['ClusterPrivateNetworkArgs'] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]] public_networks: Public endpoint information.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] status: The status of the cluster (e.g., "ready", "creating", "configuring").
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] updated_at: Date and time of cluster last update (RFC 3339 format).
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_amount is not None:
            pulumi.set(__self__, "node_amount", node_amount)
        if node_type is not None:
            pulumi.set(__self__, "node_type", node_type)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_networks is not None:
            pulumi.set(__self__, "public_networks", public_networks)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if volume_size_in_gb is not None:
            pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date and time of cluster creation (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Kafka cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Number of nodes in the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_amount")

    @node_amount.setter
    def node_amount(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_amount", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Node type to use for the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['ClusterPrivateNetworkArgs']]:
        """
        Private network endpoint information.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['ClusterPrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicNetworks")
    def public_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]]]:
        """
        Public endpoint information.
        """
        return pulumi.get(self, "public_networks")

    @public_networks.setter
    def public_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterPublicNetworkArgs']]]]):
        pulumi.set(self, "public_networks", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the cluster (e.g., "ready", "creating", "configuring").
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date and time of cluster last update (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Volume size in GB. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "volume_size_in_gb", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "volume_type", value)


@pulumi.type_token("scaleway:kafka/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_amount: Optional[pulumi.Input[_builtins.int]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Kafka clusters.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/managed-services/kafka/).

        > **Important:** The Kafka product is currently in Public Beta.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            private_network={
                "pn_id": pn.id,
            })
        ```

        ### With Tags

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            tags=[
                "production",
                "messaging",
            ],
            private_network={
                "pn_id": pn.id,
            })
        ```

        ## Import

        Kafka clusters can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:kafka/cluster:Cluster main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Kafka clusters.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/managed-services/kafka/).

        > **Important:** The Kafka product is currently in Public Beta.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            private_network={
                "pn_id": pn.id,
            })
        ```

        ### With Tags

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.Vpc("main",
            region="fr-par",
            name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            region="fr-par",
            vpc_id=main.id)
        main_cluster = scaleway.kafka.Cluster("main",
            name="my-kafka-cluster",
            version="3.9.0",
            node_amount=1,
            node_type="KAFK-PLAY-NANO",
            volume_type="sbs_5k",
            volume_size_in_gb=10,
            user_name="admin",
            password="thiZ_is_v&ry_s3cret",
            tags=[
                "production",
                "messaging",
            ],
            private_network={
                "pn_id": pn.id,
            })
        ```

        ## Import

        Kafka clusters can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:kafka/cluster:Cluster main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_amount: Optional[pulumi.Input[_builtins.int]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network: Optional[pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["name"] = name
            if node_amount is None and not opts.urn:
                raise TypeError("Missing required property 'node_amount'")
            __props__.__dict__["node_amount"] = node_amount
            if node_type is None and not opts.urn:
                raise TypeError("Missing required property 'node_type'")
            __props__.__dict__["node_type"] = node_type
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["private_network"] = private_network
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_name"] = user_name
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            if volume_size_in_gb is None and not opts.urn:
                raise TypeError("Missing required property 'volume_size_in_gb'")
            __props__.__dict__["volume_size_in_gb"] = volume_size_in_gb
            if volume_type is None and not opts.urn:
                raise TypeError("Missing required property 'volume_type'")
            __props__.__dict__["volume_type"] = volume_type
            __props__.__dict__["created_at"] = None
            __props__.__dict__["public_networks"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Cluster, __self__).__init__(
            'scaleway:kafka/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_amount: Optional[pulumi.Input[_builtins.int]] = None,
            node_type: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            private_network: Optional[pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            public_networks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ClusterPublicNetworkArgs', 'ClusterPublicNetworkArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            user_name: Optional[pulumi.Input[_builtins.str]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None,
            volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
            volume_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Date and time of cluster creation (RFC 3339 format).
        :param pulumi.Input[_builtins.str] name: Name of the Kafka cluster.
        :param pulumi.Input[_builtins.int] node_amount: Number of nodes in the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] node_type: Node type to use for the cluster. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] password: Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        :param pulumi.Input[Union['ClusterPrivateNetworkArgs', 'ClusterPrivateNetworkArgsDict']] private_network: Private network endpoint information.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the cluster is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ClusterPublicNetworkArgs', 'ClusterPublicNetworkArgsDict']]]] public_networks: Public endpoint information.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the cluster should be created.
        :param pulumi.Input[_builtins.str] status: The status of the cluster (e.g., "ready", "creating", "configuring").
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: List of tags to apply to the cluster.
        :param pulumi.Input[_builtins.str] updated_at: Date and time of cluster last update (RFC 3339 format).
        :param pulumi.Input[_builtins.str] user_name: Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] version: Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size in GB. Changing this forces recreation of the cluster.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["node_amount"] = node_amount
        __props__.__dict__["node_type"] = node_type
        __props__.__dict__["password"] = password
        __props__.__dict__["private_network"] = private_network
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public_networks"] = public_networks
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["version"] = version
        __props__.__dict__["volume_size_in_gb"] = volume_size_in_gb
        __props__.__dict__["volume_type"] = volume_type
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date and time of cluster creation (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Kafka cluster.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> pulumi.Output[_builtins.int]:
        """
        Number of nodes in the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_amount")

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Output[_builtins.str]:
        """
        Node type to use for the cluster. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "node_type")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for the Kafka user. Required if `user_name` is specified. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> pulumi.Output[Optional['outputs.ClusterPrivateNetwork']]:
        """
        Private network endpoint information.
        """
        return pulumi.get(self, "private_network")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the cluster is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicNetworks")
    def public_networks(self) -> pulumi.Output[Sequence['outputs.ClusterPublicNetwork']]:
        """
        Public endpoint information.
        """
        return pulumi.get(self, "public_networks")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the cluster should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the cluster (e.g., "ready", "creating", "configuring").
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of tags to apply to the cluster.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Date and time of cluster last update (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username for the Kafka user. If not specified, no user will be created. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "user_name")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        Kafka version to use (e.g., "3.9.0"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> pulumi.Output[_builtins.int]:
        """
        Volume size in GB. Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of volume where data is stored (e.g., "sbs_5k", "sbs_15k"). Changing this forces recreation of the cluster.
        """
        return pulumi.get(self, "volume_type")

